@@ -4,7 +4,7 @@ from enum import IntEnum
 from pydantic import BaseModel, constr
 
 
-class TipoRegistroEnum(IntEnum):
+class TipoInscricaoEnum(IntEnum):
     """
     1 - Pessoa Física
     2 - Pessoa Jurídica
@@ -14,19 +14,16 @@ class TipoRegistroEnum(IntEnum):
     cnpj = 2
 
 
-class Pagador(BaseModel):
-    tipoRegistro: TipoRegistroEnum
-    numeroRegistro: constr(max_length=14, min_length=11)
+class Pessoa(BaseModel):
+    tipoInscricao: TipoInscricaoEnum
+    numeroInscricao: constr(max_length=14, min_length=11)
     nome: constr(max_length=30)
+
+
+class PessoaComEndereco(Pessoa):
     endereco: constr(max_length=30)
     cep: constr(max_length=8, min_length=8)
     cidade: constr(max_length=30)
     bairro: constr(max_length=30)
     uf: constr(max_length=2, min_length=2)
     telefone: Optional[constr(max_length=30)]
-
-
-class Avalista(BaseModel):
-    tipoRegistro: TipoRegistroEnum
-    numeroRegistro: constr(max_length=14, min_length=11)
-    nomeRegistro: constr(max_length=30)
